from django.conf import settings
from api import TorrentStreamAPI


def get_content_id(torrent_data, content_name="", duration=""):
    """Return content id by torrent data
    @param string torrent_data - Content of torrent file
    @param string content_name - Name of video, example "My home video" (optional)
    @param integer duration - Duration of video in seconds (optional)

    @return integer
    """
    api = TorrentStreamAPI(settings.TORRENT_STREAM_AFFILIATE_KEY, settings.TORRENT_STREAM_ZONE_ID)
    content_id = api.get_content_id(torrent_data, content_name, duration)
    return content_id



from django.conf import settings

TORRENT_STREAM_PLAYER = {
    'width': '650px',
    'height': '342px',
}

if hasattr(settings, 'TORRENT_STREAM_PLAYER'):
    TORRENT_STREAM_PLAYER.update(settings.TORRENT_STREAM_PLAYER)



AFFILIATE_KEY = ""  # see http://acestream.net/affiliate/index.php#profile-page
ZONE_ID = ""  # ID of board, see http://acestream.net/affiliate/index.php#zone-page
XML_API_URL = "http://torrentstream.net/api/xml"



from django import template

from ..helpers import get_content_id
from ..settings import TORRENT_STREAM_PLAYER
from ..exceptions import FailedResponse, ServerFault

register = template.Library()


def receive_content_id(torrent_file):
    """content_id extractor
    """
    content = ""
    if hasattr(torrent_file, 'read'):
        content = torrent_file.read()
    try:
        return get_content_id(content)
    except (FailedResponse, ServerFault):
        return None


def torrent_stream_player(torrent_file):
    """Common context for player/button templates
    """
    return {
        'content_id': receive_content_id(torrent_file),
        'TORRENT_STREAM_PLAYER': TORRENT_STREAM_PLAYER,
    }


def torrent_stream_button(*args):
    return torrent_stream_player(*args)

register.inclusion_tag('torrent_stream/player.html')(torrent_stream_player)
register.inclusion_tag('torrent_stream/button.html')(torrent_stream_button)



from helpers import get_content_id
from exceptions import ServerFault


def receive_content_id(torrent_file):
    """content_id extractor
    """
    content = ""
    if hasattr(torrent_file, 'read'):
        content = torrent_file.read()
    try:
        return get_content_id(content)
    except ServerFault:
        return None



import base64
import os.path
import requests

from lxml import etree
from django.template import Context, Template

import default_settings
import exceptions


class TorrentStreamAPI(object):
    _content_id = None

    def __init__(self, affiliate_key, zone_id, xml_api_url=None):
        """
        @param string affiliate_key -
        @param integer zone_id -
        @see http://acestream.net/affiliate/index.php
        """
        self.affiliate_key = affiliate_key
        self.zone_id = zone_id
        self.xml_api_url = xml_api_url or default_settings.XML_API_URL

    def send_request(self, template_name, params):
        """Send XML request
        @param string template_name - Path to xml-template
        @param dict params - Context for xml-template
        @return string - Response in XML
        """
        xml_template = open(os.path.join(os.path.dirname(__file__), template_name)).read()
        xml_content = Template(xml_template).render(Context(params))
        response = requests.post(self.xml_api_url, xml_content)
        return response.content

    def get_content_id(self, torrent_data, content_name=None, duration=None):
        """
        @param string torrent_data - Content of torrent file
        @param string content_name - Name of video, example "My home video" (optional)
        @param integer duration - Duration of video in seconds (optional)
        """
        self.torrent_data = base64.encodestring(torrent_data)
        self.content_name = content_name
        self.duration = duration

        if not self._content_id:
            # Request for getting Content ID
            try:
                xml_result = self.send_request("templates/request.xml", params=vars(self))
            except (Exception, ), e:
                raise exceptions.ServerFault(e.message)
            tree = etree.HTML(xml_result)
            statuses = tree.xpath('//response/status')
            if statuses:
                status = statuses[0]
                if status.text == 'accepted':
                    self._content_id = tree.xpath('//response/id/text()')[0]
                else:
                    error = "TorrentStream Error: {0} (Errcode: {1})".format(status.attrib.get('error'), status.attrib.get('errorcode'))
                    raise exceptions.FailedResponse(error)
        return self._content_id



from setuptools import setup
from torrent_stream import __version__

long_description = ""
try:
    readme = open("README.rst")
    long_description = str(readme.read())
    readme.close()
except:
    pass

setup(
    name='django-torrent-stream',
    version=__version__,
    description="Wraps the Torrent Stream http://torrentstream.org/",
    long_description=long_description,
    keywords='django, torrent, torrent stream',
    author='Mikhail Andreev',
    author_email='x11org@gmail.com',
    url='http://github.com/adw0rd/django-torrent-stream',
    license='BSD',
    packages=['torrent_stream', ],
    install_requires=['requests', ],
    zip_safe=False,
    include_package_data=True,
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Programming Language :: Python",
        "Framework :: Django",
        "License :: OSI Approved :: BSD License",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)
